@@ -17,15 +17,14 @@ class Command(BaseCommand):
     def handle(self, *args, **options):
         from viddler.models import ViddlerVideo, make_model_from_api
         from viddler.settings import get_viddler
-        from time import strptime
         viddler = get_viddler()
         viddler_kwargs = {'per_page': 100}
         try:
             if options['since']:
-                viddler_kwargs['min_upload_date'] = strptime(options['since'], '%Y-%m-%d')
+                viddler_kwargs['min_upload_date'] = options['since']
             else:
                 v = ViddlerVideo.objects.latest('upload_time')
-                viddler_kwargs['min_upload_date'] = v.upload_time
+                viddler_kwargs['min_upload_date'] = v.upload_time.strftime('%Y-%m-%d')
         except (ViddlerVideo.DoesNotExist, ValueError):
             pass
 
